import React from 'react';
import ReactDOM from 'react-dom/client';

/**
 * Importing the global stylesheet and the root App component for the application.
 * @param {string} './index.css' - The path to the global stylesheet.
 * @param {string} App - The root App component of the application.
 */
import './index.css';
import App from './App';

/**
 * Main entry point for the React application.
 * Selects the root DOM element, creates a React root container, and renders the App component.
 */
const rootElement = document.getElementById('root');

if (rootElement) {
  // Creating a root container for the React application if the root element exists
  const root = ReactDOM.createRoot(rootElement);

  /**
   * Rendering the App component within React's StrictMode.
   */
  root.render(
      <React.StrictMode>
          <App />
      </React.StrictMode>
  );

} else {
  // Logging an error message if the root element is not found
  console.error('Failed to find the root element to mount the React app');

}